@@ -54,9 +54,11 @@ ge_cairo_pattern_add_color_stop(cairo_pattern_t *pattern, gdouble offset, CairoC
 void
 ge_cairo_pattern_add_shade_color_stop(cairo_pattern_t *pattern, gdouble offset, CairoColor *color, gdouble shade)
 {
+	CairoColor shaded;
+
 	g_return_if_fail (pattern && color && (shade >= 0) && (shade <= 3));
 
-	CairoColor shaded = *color;
+	shaded = *color;
 
 	if (shade != 1)
 	{
@@ -81,7 +83,6 @@ void glide_draw_pattern_fill(cairo_t *canvas,
 					gint width,
 					gint height)
 {
-
 	cairo_matrix_t original_matrix, current_matrix;
 
 	if (pattern->operator == CAIRO_OPERATOR_DEST)
@@ -245,13 +246,19 @@ do_glide_draw_border_with_gap(cairo_t *canvas,
 
 	if (bevel_style == GLIDE_BEVEL_STYLE_FLAT) 
 	{
-		cairo_save(canvas);
+		if (gap_size)
+		{
+			cairo_save(canvas);
 
-		glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
+			glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
+		}
 
 		ge_cairo_simple_border(canvas, &darktone, &darktone, x, y, width, height, (gap_side == GLIDE_SIDE_NONE) || ((gap_side == GLIDE_SIDE_BOTTOM) && (gap_size != width)) || ((gap_side == GLIDE_SIDE_RIGHT) && (gap_pos != 0)));
 
-		cairo_restore(canvas);
+		if (gap_size)
+		{
+			cairo_restore(canvas);
+		}
 
 		return;
 	}   
@@ -283,15 +290,28 @@ do_glide_draw_border_with_gap(cairo_t *canvas,
 				color2 = color1;
 				color1 = tmp;							
 			}
-			cairo_save(canvas);
-			glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
-			ge_cairo_simple_border(canvas, &color2, &color1, x, y, width, height, outer_overlap);
-			cairo_restore(canvas);
 
-			cairo_save(canvas);
-			glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos + 1, gap_size - 2);
+			if (gap_size)
+			{
+				cairo_save(canvas);
+				glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
+			}
+
+			ge_cairo_simple_border(canvas, &color2, &color1, x, y, width, height, outer_overlap);
+
+			if (gap_size)
+			{
+				cairo_restore(canvas);
+				cairo_save(canvas);
+				glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos + 1, gap_size - 2);
+			}
+
 			ge_cairo_simple_border(canvas, &color1, &color2, x+1, y+1, width-2, height-2, inner_overlap);
-			cairo_restore(canvas);
+
+			if (gap_size)
+			{
+				cairo_restore(canvas);
+			}
 		}	
 		break;
       
@@ -314,11 +334,17 @@ do_glide_draw_border_with_gap(cairo_t *canvas,
 					color1 = tmp;							
 				}
 
-				cairo_save(canvas);
-				glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
-				ge_cairo_simple_border(canvas, &color1, &color2, x, y, width, height, 						(gap_side == GLIDE_SIDE_NONE) || ((gap_side == GLIDE_SIDE_BOTTOM) && (gap_size != width)) || ((gap_side == GLIDE_SIDE_RIGHT) && (gap_pos != 0))
-);
-				cairo_restore(canvas);
+				if (gap_size)
+				{
+					cairo_save(canvas);
+					glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
+				}
+
+				ge_cairo_simple_border(canvas, &color1, &color2, x, y, width, height, 						(gap_side == GLIDE_SIDE_NONE) || ((gap_side == GLIDE_SIDE_BOTTOM) && (gap_size != width)) || ((gap_side == GLIDE_SIDE_RIGHT) && (gap_pos != 0)));
+				if (gap_size)
+				{
+					cairo_restore(canvas);
+				}
 			} 
 			else 
 			{
@@ -393,15 +419,27 @@ do_glide_draw_border_with_gap(cairo_t *canvas,
 					color2 = tmp;							
 				}
 
-				cairo_save(canvas);
-				glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
-				ge_cairo_simple_border(canvas, &color1, &color3, x, y, width, height, outer_overlap);
-				cairo_restore(canvas);
+				if (gap_size)
+				{
+					cairo_save(canvas);
+					glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos, gap_size);
+				}
 
-				cairo_save(canvas);
-				glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos + 1, gap_size - 2);
+				ge_cairo_simple_border(canvas, &color1, &color3, x, y, width, height, outer_overlap);
+
+				if (gap_size)
+				{
+					cairo_restore(canvas);
+					cairo_save(canvas);
+					glide_simple_border_gap_clip(canvas, x, y, width, height, gap_side, gap_pos + 1, gap_size - 2);
+				}
+		
 				ge_cairo_simple_border(canvas, &color2, &color4, x+1, y+1, width-2, height-2, inner_overlap);
-				cairo_restore(canvas);
+
+				if (gap_size)
+				{
+					cairo_restore(canvas);
+				}
 			} 	
 		}	
 		break;
@@ -810,14 +848,17 @@ do_glide_draw_simple_circle (cairo_t *canvas,
 
       cairo_close_path (canvas);
 
+      cairo_save(canvas);
+
       cairo_clip (canvas);
 
       ge_cairo_set_color(canvas, br);
       cairo_arc(canvas, center_x, center_y, radius, 0,  2*M_PI);
       cairo_fill(canvas);
 
-      cairo_reset_clip(canvas);
+      cairo_restore(canvas);
 
+      cairo_save(canvas);
       cairo_new_path (canvas);
 
       cairo_move_to(canvas, center_x - (radius + 2), center_y - (radius + 2));
@@ -833,7 +874,7 @@ do_glide_draw_simple_circle (cairo_t *canvas,
       cairo_arc(canvas, center_x, center_y, radius, 0, 2*M_PI);
       cairo_fill(canvas);
 
-      cairo_reset_clip(canvas);
+      cairo_restore(canvas);
 }
 
 /***********************************************
@@ -1036,6 +1077,8 @@ do_glide_draw_dot (cairo_t *canvas,
 			gint x,
 			gint y)
 {
+	CairoColor mid;
+
 	cairo_save(canvas);
 
 	cairo_set_line_width (canvas, 0.5);
@@ -1053,8 +1096,6 @@ do_glide_draw_dot (cairo_t *canvas,
 	cairo_rectangle (canvas, x, y + 1, 0.5, 0.5);
 	cairo_stroke(canvas);
 
-	CairoColor mid;
-
 	ge_blend_color(dark, light, &mid);	
 
 	ge_cairo_set_color(canvas, &mid);	
@@ -1155,7 +1196,7 @@ glide_gtk2_engine_hack_menu_shell_destroy(GtkWidget *widget,
                        GdkEvent *event,
                        gpointer user_data)
 {
-  glide_gtk2_engine_hack_menu_shell_cleanup_signals(widget);
+ glide_gtk2_engine_hack_menu_shell_cleanup (widget);
   
   return FALSE;
 }
