@@ -17,13 +17,13 @@ Thinice Authors: Tim Gerla <timg@rrv.net>
 #define YTHICKNESS(style) (style->ythickness)
 #define XTHICKNESS(style) (style->xthickness)
 
-static GtkStyleClass *parent_class = NULL;
+static GtkStyleClass *mist_parent_style_class = NULL;
 
 static void mist_style_init       (MistStyle      *style);
 static void mist_style_class_init (MistStyleClass *klass);
 
 static GtkShadowType
-get_shadow_type (GtkStyle *style, const char *detail, GtkShadowType requested)
+mist_get_shadow_type (GtkStyle *style, const char *detail, GtkShadowType requested)
 {
 	GtkShadowType retval = GTK_SHADOW_NONE;
 	
@@ -91,17 +91,15 @@ mist_tab (GtkStyle *style,
 	  int x,
 	  int y,
 	  int width,
-	  int height)
+	  int height,
+	  GtkPositionType gap_side)
 {
 	MistStyle *mist_style = MIST_STYLE (style);
 
-	GtkNotebook *notebook;
-	int orientation;
-	
-	notebook = GTK_NOTEBOOK(widget);
-	orientation = notebook->tab_pos;
+	cairo_t *cr;
+	CairoColor *light, *dark;
 		
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	if ((!style->bg_pixmap[state_type]) || GDK_IS_PIXMAP(window)) 
 	{
@@ -116,14 +114,11 @@ mist_tab (GtkStyle *style,
 			 state_type, area, x, y, width, height);
 	}
 	
-
-	CairoColor *light, *dark;
-
 	light = &mist_style->color_cube.light[state_type];
 	dark = &mist_style->color_cube.dark[state_type];
 
-	switch(orientation) {
-	case GTK_POS_TOP:
+	switch(gap_side) {
+	case GTK_POS_BOTTOM:
 		ge_cairo_set_color(cr, light);	
 	
 		cairo_move_to (cr, x + 0.5, y + height - 0.5);
@@ -138,7 +133,7 @@ mist_tab (GtkStyle *style,
 		cairo_stroke (cr);
 
 		break;
-	case GTK_POS_BOTTOM:
+	case GTK_POS_TOP:
 		ge_cairo_set_color(cr, light);	
 	
 		cairo_move_to (cr, x + 0.5, y + 0.5);
@@ -152,7 +147,7 @@ mist_tab (GtkStyle *style,
 		cairo_line_to (cr, x + width - 0.5, y + 0.5);
 		cairo_stroke (cr);
 		break;
-	case GTK_POS_LEFT:
+	case GTK_POS_RIGHT:
 		ge_cairo_set_color(cr, light);	
 	
 		cairo_move_to (cr, x + 0.5, y + height - 0.5);
@@ -167,7 +162,7 @@ mist_tab (GtkStyle *style,
 		cairo_stroke (cr);
 
 		break;
-	case GTK_POS_RIGHT:
+	case GTK_POS_LEFT:
 		ge_cairo_set_color(cr, light);	
 	
 		cairo_move_to (cr, x + 0.5, y + 0.5);
@@ -228,7 +223,7 @@ mist_draw_border (GtkStyle *style,
 }
 
 static void
-draw_hline(GtkStyle *style,
+mist_style_draw_hline(GtkStyle *style,
            GdkWindow *window,
            GtkStateType state_type,
            GdkRectangle *area,
@@ -243,11 +238,12 @@ draw_hline(GtkStyle *style,
 	int thickness_light;
 	int thickness_dark;
 	int i;
-	
+	cairo_t *cr;
+
 	g_return_if_fail(style != NULL);
 	g_return_if_fail(window != NULL);
 	
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	if (CHECK_DETAIL(detail, "hseparator") 
 	    || CHECK_DETAIL(detail, "menuitem") 
@@ -297,7 +293,7 @@ draw_hline(GtkStyle *style,
 }
 
 static void
-draw_vline(GtkStyle *style,
+mist_style_draw_vline(GtkStyle *style,
            GdkWindow *window,
            GtkStateType state_type,
            GdkRectangle *area,
@@ -312,11 +308,12 @@ draw_vline(GtkStyle *style,
 	int thickness_light;
 	int thickness_dark;
 	int i;
+	cairo_t *cr;
 
 	g_return_if_fail(style != NULL);
 	g_return_if_fail(window != NULL);
 	
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	if (CHECK_DETAIL(detail, "vseparator") 
 	    || CHECK_DETAIL(detail, "toolbar") 
@@ -366,7 +363,7 @@ draw_vline(GtkStyle *style,
 }
 
 static void
-draw_shadow(GtkStyle *style,
+mist_style_draw_shadow(GtkStyle *style,
 	    GdkWindow *window,
 	    GtkStateType state_type,
 	    GtkShadowType shadow_type,
@@ -379,21 +376,22 @@ draw_shadow(GtkStyle *style,
 	    int height)
 {
 	MistStyle *mist_style = MIST_STYLE (style);
+	cairo_t *cr;
 
 	g_return_if_fail(style != NULL);
 	g_return_if_fail(window != NULL);
 	
 	SANITIZE_SIZE
 
-	shadow_type = get_shadow_type (style, detail, shadow_type);
+	shadow_type = mist_get_shadow_type (style, detail, shadow_type);
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	if (state_type == GTK_STATE_INSENSITIVE && shadow_type != GTK_SHADOW_NONE) {
 		shadow_type = GTK_SHADOW_ETCHED_IN;
 	}
 	
-	if (CHECK_DETAIL(detail, "frame") && widget->parent && GTK_IS_STATUSBAR (widget->parent)) {
+	if (CHECK_DETAIL(detail, "frame") && widget && widget->parent && GTK_IS_STATUSBAR (widget->parent)) {
 		if (shadow_type != GTK_SHADOW_NONE) {
 			ge_cairo_set_color(cr, &mist_style->color_cube.dark[GTK_STATE_NORMAL]);	
 	
@@ -410,7 +408,7 @@ draw_shadow(GtkStyle *style,
 }
 
 static void
-draw_polygon(GtkStyle *style,
+mist_style_draw_polygon(GtkStyle *style,
              GdkWindow *window,
              GtkStateType state_type,
              GtkShadowType shadow_type,
@@ -440,6 +438,7 @@ draw_polygon(GtkStyle *style,
 	int                xadjust;
 	int                yadjust;
 	int                i;
+	cairo_t           *cr;
 
 	g_return_if_fail(style != NULL);
 	g_return_if_fail(window != NULL);
@@ -474,7 +473,7 @@ draw_polygon(GtkStyle *style,
 		return;
 	}
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	if (fill)
 		ge_cairo_polygon(cr, &mist_style->color_cube.bg[state_type], points, npoints);
@@ -532,7 +531,7 @@ draw_polygon(GtkStyle *style,
 }
 
 static void
-draw_diamond(GtkStyle * style,
+mist_style_draw_diamond(GtkStyle * style,
              GdkWindow * window,
              GtkStateType state_type,
              GtkShadowType shadow_type,
@@ -548,6 +547,7 @@ draw_diamond(GtkStyle * style,
 
 	int half_width;
 	int half_height;
+	cairo_t *cr;
 	
 	g_return_if_fail(style != NULL);
 	g_return_if_fail(window != NULL);	
@@ -557,7 +557,7 @@ draw_diamond(GtkStyle * style,
 	half_width = width / 2;
 	half_height = height / 2;
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	switch (shadow_type) {
 	case GTK_SHADOW_IN:
@@ -646,7 +646,7 @@ draw_diamond(GtkStyle * style,
 }
 
 static void
-draw_box(GtkStyle *style,
+mist_style_draw_box(GtkStyle *style,
          GdkWindow *window,
          GtkStateType state_type,
          GtkShadowType shadow_type,
@@ -661,7 +661,7 @@ draw_box(GtkStyle *style,
 	MistStyle *mist_style = MIST_STYLE (style);
 
 	CairoColor *light, *dark;
-	GtkOrientation orientation;
+	cairo_t *cr;
 	
 	g_return_if_fail (style != NULL);
 	g_return_if_fail (window != NULL);
@@ -675,7 +675,7 @@ draw_box(GtkStyle *style,
 	light = &mist_style->color_cube.light[state_type];
 	dark = &mist_style->color_cube.dark[state_type];
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 	
 	if (CHECK_DETAIL(detail, "optionmenutab")) {
 		ge_cairo_line(cr, dark, x - 5, y, x - 5, y + height);
@@ -703,10 +703,6 @@ draw_box(GtkStyle *style,
 				       x + width - 1, y + height - 1);
 
 		}
-	} else if (CHECK_DETAIL(detail, "tab")) {
-		mist_tab(style, window, state_type, 
-			 shadow_type, area, widget,
-			 detail, x, y, width, height);
 	} else  if (CHECK_DETAIL(detail, "bar")) {
 		if (width > 1 && height > 1) {
 			ge_cairo_set_color(cr, &mist_style->color_cube.base[GTK_STATE_SELECTED]);	
@@ -758,7 +754,7 @@ draw_box(GtkStyle *style,
 						   state_type, area,
 						   x, y, width, height);
 
-		shadow_type = get_shadow_type (style, detail, shadow_type);
+		shadow_type = mist_get_shadow_type (style, detail, shadow_type);
 		if (state_type == GTK_STATE_INSENSITIVE && shadow_type != GTK_SHADOW_NONE) {
 			shadow_type = GTK_SHADOW_ETCHED_IN;
 		}
@@ -774,7 +770,7 @@ draw_box(GtkStyle *style,
 }
 
 static void
-draw_check(GtkStyle *style,
+mist_style_draw_check(GtkStyle *style,
            GdkWindow *window,
            GtkStateType state_type,
            GtkShadowType shadow_type,
@@ -787,10 +783,11 @@ draw_check(GtkStyle *style,
            int height)
 {
 	MistStyle *mist_style = MIST_STYLE (style);
+	cairo_t *cr;
 
 	SANITIZE_SIZE
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	ge_cairo_set_color(cr, &mist_style->color_cube.base[state_type == GTK_STATE_INSENSITIVE ? GTK_STATE_INSENSITIVE : GTK_STATE_NORMAL ]);	
 	cairo_rectangle(cr, x + 1, y + 1, width - 3, height - 3);
@@ -835,7 +832,7 @@ draw_check(GtkStyle *style,
 }
 
 static void
-draw_option(GtkStyle *style,
+mist_style_draw_option(GtkStyle *style,
             GdkWindow *window,
             GtkStateType state_type,
             GtkShadowType shadow_type,
@@ -848,10 +845,11 @@ draw_option(GtkStyle *style,
             int height)
 {
 	MistStyle *mist_style = MIST_STYLE (style);
+	cairo_t *cr;
 
 	SANITIZE_SIZE
 
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	cairo_arc(cr, x + floor(width/2), y + floor(height/2), floor(width/2) - 0.5, 0 , 2 * M_PI);
 	ge_cairo_set_color(cr, &mist_style->color_cube.dark[state_type == GTK_STATE_INSENSITIVE ? GTK_STATE_INSENSITIVE : GTK_STATE_NORMAL]);	
@@ -899,7 +897,7 @@ draw_option(GtkStyle *style,
 }
 
 static void
-draw_shadow_gap(GtkStyle *style,
+mist_style_draw_shadow_gap(GtkStyle *style,
                 GdkWindow *window,
                 GtkStateType state_type,
                 GtkShadowType shadow_type,
@@ -918,13 +916,14 @@ draw_shadow_gap(GtkStyle *style,
 
 	CairoColor *color1 = NULL;
 	CairoColor *color2 = NULL;
+	cairo_t *cr;
 	
 	g_return_if_fail (window != NULL);
 	
 	SANITIZE_SIZE
-	shadow_type = get_shadow_type (style, detail, shadow_type);
+	shadow_type = mist_get_shadow_type (style, detail, shadow_type);
 	
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	switch (shadow_type) {
 	case GTK_SHADOW_NONE:
@@ -1038,7 +1037,7 @@ draw_shadow_gap(GtkStyle *style,
 }
 
 static void
-draw_box_gap(GtkStyle *style,
+mist_style_draw_box_gap(GtkStyle *style,
 	     GdkWindow *window,
 	     GtkStateType state_type,
 	     GtkShadowType shadow_type,
@@ -1060,13 +1059,13 @@ draw_box_gap(GtkStyle *style,
 					   state_type, area,
 					   x, y, width, height);
 
-	draw_shadow_gap (style, window, state_type, shadow_type,
+	mist_style_draw_shadow_gap (style, window, state_type, shadow_type,
 			 area, widget, detail, x, y, width, height, 
 			 gap_side, gap_x, gap_width);
 }
 
 static void
-draw_extension(GtkStyle *style,
+mist_style_draw_extension(GtkStyle *style,
                GdkWindow *window,
                GtkStateType state_type,
                GtkShadowType shadow_type,
@@ -1086,9 +1085,8 @@ draw_extension(GtkStyle *style,
 	
 	SANITIZE_SIZE
 
-	gtk_paint_box(style, window, state_type, shadow_type, 
-		      area, widget, detail,
-		      x, y, width, height);
+	mist_tab(style, window, state_type, shadow_type, area,
+		 widget, detail, x, y, width, height, gap_side);
 	
 	switch (gap_side) {
 	case GTK_POS_TOP:
@@ -1123,7 +1121,7 @@ draw_extension(GtkStyle *style,
 }
 
 static void
-draw_handle(GtkStyle *style,
+mist_style_draw_handle(GtkStyle *style,
             GdkWindow *window,
             GtkStateType state_type,
             GtkShadowType shadow_type,
@@ -1141,6 +1139,7 @@ draw_handle(GtkStyle *style,
 	CairoColor *light, *dark;
 	GdkRectangle dest;
 	int modx, mody;
+	cairo_t *cr;
 	
 	g_return_if_fail(style != NULL);
 	g_return_if_fail(window != NULL);
@@ -1170,7 +1169,7 @@ draw_handle(GtkStyle *style,
 		modx = 0; mody = 4;
 	}
 	
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, &dest);
+	cr = ge_gdk_drawable_to_cairo (window, &dest);
 
 	mist_dot(cr,
 		 light, dark,
@@ -1189,7 +1188,7 @@ draw_handle(GtkStyle *style,
 }
 
 static void
-draw_resize_grip(GtkStyle *style,
+mist_style_draw_resize_grip(GtkStyle *style,
 		 GdkWindow *window,
 		 GtkStateType state_type,
 		 GdkRectangle *area,
@@ -1207,6 +1206,7 @@ draw_resize_grip(GtkStyle *style,
 	int xi, yi;
 	int max_x, max_y;
 	int threshold;
+	cairo_t *cr;
 	
 	g_return_if_fail(style != NULL);
 	g_return_if_fail(window != NULL);
@@ -1291,8 +1291,7 @@ draw_resize_grip(GtkStyle *style,
 	
 	threshold = max_x;
 	
-
-	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
+	cr = ge_gdk_drawable_to_cairo (window, area);
 
 	for (xi = 0; xi <= max_x; xi++) {
 		for (yi = 0; yi <= max_y; yi++) {
@@ -1334,7 +1333,7 @@ draw_resize_grip(GtkStyle *style,
 }
 
 static void
-draw_string (GtkStyle      *style,
+mist_style_draw_string (GtkStyle      *style,
 	     GdkWindow     *window,
 	     GtkStateType   state_type,
 	     GdkRectangle  *area,
@@ -1361,7 +1360,7 @@ draw_string (GtkStyle      *style,
 }
 
 static void
-draw_layout (GtkStyle        *style,
+mist_style_draw_layout (GtkStyle        *style,
 	     GdkWindow       *window,
 	     GtkStateType     state_type,
 	     gboolean         use_text,
@@ -1440,7 +1439,7 @@ scale_or_ref (GdkPixbuf *src,
 }
 
 static GdkPixbuf *
-render_icon (GtkStyle            *style,
+mist_style_render_icon (GtkStyle            *style,
 	     const GtkIconSource *source,
 	     GtkTextDirection     direction,
 	     GtkStateType         state,
@@ -1550,7 +1549,7 @@ mist_style_realize (GtkStyle * style)
   MistStyle *mist_style = MIST_STYLE (style);
   int i;
  
-  parent_class->realize (style);
+  mist_parent_style_class->realize (style);
  
   ge_gtk_style_to_cairo_color_cube (style, &mist_style->color_cube);
 }
@@ -1560,25 +1559,25 @@ mist_style_class_init (MistStyleClass *klass)
 {
 	GtkStyleClass *style_class = GTK_STYLE_CLASS (klass);
 	
-	parent_class = g_type_class_peek_parent (klass);
+	mist_parent_style_class = g_type_class_peek_parent (klass);
 	
 	style_class->realize = mist_style_realize;
 
-	style_class->draw_hline = draw_hline;
-	style_class->draw_vline = draw_vline;
-	style_class->draw_shadow = draw_shadow;
-	style_class->draw_polygon = draw_polygon;
-	style_class->draw_diamond = draw_diamond;
-	style_class->draw_box = draw_box;
-	style_class->draw_tab = draw_box;
-	style_class->draw_check = draw_check;
-	style_class->draw_option = draw_option;
-	style_class->draw_shadow_gap = draw_shadow_gap;
-	style_class->draw_box_gap = draw_box_gap;
-	style_class->draw_extension = draw_extension;
-	style_class->draw_handle = draw_handle;
-	style_class->draw_resize_grip = draw_resize_grip;
-	style_class->draw_string = draw_string;
-	style_class->draw_layout = draw_layout;
-	style_class->render_icon = render_icon;
+	style_class->draw_hline = mist_style_draw_hline;
+	style_class->draw_vline = mist_style_draw_vline;
+	style_class->draw_shadow = mist_style_draw_shadow;
+	style_class->draw_polygon = mist_style_draw_polygon;
+	style_class->draw_diamond = mist_style_draw_diamond;
+	style_class->draw_box = mist_style_draw_box;
+	style_class->draw_tab = mist_style_draw_box;
+	style_class->draw_check = mist_style_draw_check;
+	style_class->draw_option = mist_style_draw_option;
+	style_class->draw_shadow_gap = mist_style_draw_shadow_gap;
+	style_class->draw_box_gap = mist_style_draw_box_gap;
+	style_class->draw_extension = mist_style_draw_extension;
+	style_class->draw_handle = mist_style_draw_handle;
+	style_class->draw_resize_grip = mist_style_draw_resize_grip;
+	style_class->draw_string = mist_style_draw_string;
+	style_class->draw_layout = mist_style_draw_layout;
+	style_class->render_icon = mist_style_render_icon;
 }
